package com.ruoyi.ibs.list.service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.CustInfoBusiness;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.ibs.list.domain.CustInfoBusinessVo;
import com.ruoyi.ibs.list.domain.SysGroupCustomer;

import javax.servlet.http.HttpServletResponse;


/**
 * 企业客户基本信息Service接口
 * 
 * @author ruoyi
 * @date 2024-10-28
 */
public interface ICustInfoBusinessService 
{
    /**
     * 查询企业客户基本信息
     * 
     * @param id 企业客户基本信息主键
     * @return 企业客户基本信息
     */
    public CustInfoBusiness selectCustInfoBusinessById(Long id);

    /**
     * 查询360视图企业客户基本信息
     *
     * @param id 企业客户基本信息主键
     * @return 企业客户基本信息
     */
    public CustInfoBusinessVo selectCustInfoBusinessVoByCustId(String custId);

    /**
     * 查询企业客户基本信息列表
     * 
     * @param custInfoBusiness 企业客户基本信息
     * @return 企业客户基本信息集合
     */
    public List<CustInfoBusiness> selectCustInfoBusinessList(CustInfoBusiness custInfoBusiness);
    public List<CustInfoBusiness> selectCustInfoBusinessListByKeyword(String keyword);

    /**
     * 新增企业客户基本信息
     * 
     * @param custInfoBusiness 企业客户基本信息
     * @return 结果
     */
    public int insertCustInfoBusiness(CustInfoBusiness custInfoBusiness);

    /**
     * 企业营销建档
     *
     * @param custInfoBusiness 企业客户基本信息
     * @return 结果
     */
    public AjaxResult insertCustInfoBusinessVo(CustInfoBusiness custInfoBusiness, String relatePerson);

    /**
     * 修改企业客户基本信息
     * 
     * @param custInfoBusiness 企业客户基本信息
     * @return 结果
     */
    public AjaxResult updateCustInfoBusiness(CustInfoBusiness custInfoBusiness);

    /**
     * 批量删除企业客户基本信息
     * 
     * @param ids 需要删除的企业客户基本信息主键集合
     * @return 结果
     */
    public int deleteCustInfoBusinessByIds(Long[] ids);

    /**
     * 删除企业客户基本信息信息
     * 
     * @param id 企业客户基本信息主键
     * @return 结果
     */
    public int deleteCustInfoBusinessById(Long id);

    public CustInfoBusiness selectCustInfoBusinessByCustId(String custId);

    void exportBusinessDetail(HttpServletResponse response, String custId) throws Exception;

    public int insertCustomersToBusinessByScCode(List<SysGroupCustomer> sysGroupCustomers);

    public List<SysDictData> getRegStatus();
}
